# Overall Report

Locality: {{{locality}}}  
Valuation date: {{{val_date}}}  

## Executive Summary

Open AVM Kit provides a comprehensive set of automatically generated reports alongside its modeling suite. These aim to align with both IAAO standards and the needs of property assessment oversight bodies.

The four most important reports are:

| Report Name | Purpose                     |
|-------------|-----------------------------|
| Ratio study | Accuracy                    |
| Horizontal equity | Consistency                 |
| Vertical equity | Fairness                    |
| Sales scrutiny | Validity |
| Land report | Land value assessment |

Additionally, informational reports are provided that give detailed breakdowns of every aspect of the modeling process:

| Report Name      | Purpose                                                        |
|------------------|----------------------------------------------------------------|
| Modeling process | Detailed breakdown of the modeling process                     |
| Value drivers    | Identifying which variables are the principal drivers of value |


Prior to modeling, the entire dataset is broken down into different categories of properties: for example `residential single-family`, `residential townhomes`, `commercial`, etc. Not only is each group modeled separately, each modeling group gets its own version of each of the above individual reports. Overall statistics for each modeling group are provided here, in the overall report.

## Ratio Study

The ratio study report is the primary document used to assess the accuracy of the model. It compares the predicted values of the model against known selling prices. Additionally, the ratio study report provides breakdowns of the model's performance by various different factors, including location, property type, and price tier.